==> map-2.30.jar: map/Const.java <==
package map;

import java.awt.GraphicsEnvironment;
import java.io.File;
import java.io.InputStream;
import java.net.URL;
import java.util.Arrays;

/**
 * 定数を集めたクラスです。
 * @author Kumano Tatsuo
 * Created on 2005/05/03 9:07:02
 */
public class Const {

	/**
	 * ファイルシステムのセパレータ
	 */
	public static String SEPARATOR = File.separator;

	/**
	 * 地図を先読みする範囲
	 */
	public static final double PRE_LOAD_COEFFICIENT = 0;

	/**
	 * 一度読み込んだ地図を捨てずに置いておく範囲
	 */
	public static final double KEEP_COFFICIENT = 1;

	/**
	 * 国土数値情報の市区町村データを読み込む倍率
	 */
	public static final double LOAD_CITIES_ZOOM = 0.003;
	
	/**
	 * 丁目のポリゴンデータを読み込む表示倍率
	 */
	public static final double LOAG_GYOUSEI_ZOOM = 0.15;

	/**
	 * 全てのデータを読み込む表示倍率 
	 */
	public static final double LOAD_ALL_ZOOM = 0.3;
	
	/**
	 * 地図データの配布URL 
	 */
	public static final String BASE_URL = "http://sdf.gsi.go.jp/";

	/**
	 * キャッシュディレクトリの相対パス 
	 */
	public static final String CACHE_DIR = ".map" + File.separator + "cache";

	/**
	 * 展開済みファイルの一覧を記録したファイル
	 */
	public static final String EXTRACTED_LOG_FILE = CACHE_DIR + File.separator + "extractedfiles.txt";
	
	/**
	 * ファイルの一覧が記載されているファイル
	 */
	public static final URL FILE_LIST = Const.class.getResource("files.csv");

	/**
	 * 都道府県の情報が記載されているファイル
	 */
	public static final InputStream PREFECTURES = Const.class.getResourceAsStream("prefectures.csv");

	/**
	 * 市区町村の情報が記載されているファイルの接頭語
	 */
	public static final String CITIES_PREFIX = "cities_";
	
	/**
	 * 市区町村の情報が記載されているファイルの拡張子
	 */
	public static final String CITIES_SUFFIX = ".csv";
	
	/**
	 * コンポーネント間の隙間[px]
	 */
	public static final int GAP = 4;

	/**
	 * ゴシック体のフォント
	 */
	public static final String FONT_FAMILY_GOTHIC = Arrays.asList(
			GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames())
			.contains("MS UI Gothic") ? "MS UI Gothic" : Arrays.asList(
			GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames())
			.contains("Kochi Gothic") ? "Kochi Gothic" : "SansSerif";

	/**
	 * 明朝体のフォント
	 */
	public static final String FONT_FAMILY_MINCHO = Arrays.asList(
			GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames())
			.contains("ＭＳ Ｐ明朝") ? "ＭＳ Ｐ明朝" : Arrays.asList(
			GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames())
			.contains("Kochi Mincho") ? "Kochi Mincho" : "Serif";
	
}

==> map-2.31.jar: map/Const.java <==
package map;

import java.awt.GraphicsEnvironment;
import java.io.File;
import java.io.InputStream;
import java.net.URL;
import java.util.Arrays;

/**
 * 定数を集めたクラスです。
 * @author Kumano Tatsuo
 * Created on 2005/05/03 9:07:02
 */
public class Const {

	/**
	 * ファイルシステムのセパレータ
	 */
	public static String SEPARATOR = File.separator;

	/**
	 * 地図を先読みする範囲
	 */
	public static final double PRE_LOAD_COEFFICIENT = 0;

	/**
	 * 一度読み込んだ地図を捨てずに置いておく範囲
	 */
	public static final double KEEP_COFFICIENT = 1;

	/**
	 * 国土数値情報の市区町村データを読み込む倍率
	 */
	public static final double LOAD_CITIES_ZOOM = 0.003;
	
	/**
	 * 丁目のポリゴンデータを読み込む表示倍率
	 */
	public static final double LOAG_GYOUSEI_ZOOM = 0.15;

	/**
	 * 全てのデータを読み込む表示倍率 
	 */
	public static final double LOAD_ALL_ZOOM = 0.3;
	
	/**
	 * 地図データの配布URL 
	 */
	public static final String BASE_URL = "http://sdf.gsi.go.jp/";

	/**
	 * キャッシュディレクトリの相対パス 
	 */
	public static final String CACHE_DIR = ".map" + File.separator + "cache";

	/**
	 * 展開済みファイルの一覧を記録したファイル
	 */
	public static final String EXTRACTED_LOG_FILE = CACHE_DIR + File.separator + "extractedfiles.txt";
	
	/**
	 * ファイルの一覧が記載されているファイル
	 */
	public static final URL FILE_LIST = Const.class.getResource("files.csv");

	/**
	 * 全ての都道府県の情報が記載されているファイル
	 */
	public static final InputStream PREFECTURES = Const.class.getResourceAsStream("prefectures.csv");

	/**
	 * 市区町村の情報が記載されているファイルの接頭語
	 */
	public static final String CITIES_PREFIX = "cities_";
	
	/**
	 * 市区町村の情報が記載されているファイルの拡張子
	 */
	public static final String CITIES_SUFFIX = ".csv";

	/**
	 * 高精度の都道府県の情報が記載されているファイルの接頭語
	 */
	public static final String PREFECTURE_PREFIX = "prefecture_";
	
	/**
	 * 高精度の都道府県の情報が記載されているファイルの拡張子
	 */
	public static final String PREFECTURE_SUFFIX = ".csv";

	/**
	 * コンポーネント間の隙間[px]
	 */
	public static final int GAP = 4;

	/**
	 * ゴシック体のフォント
	 */
	public static final String FONT_FAMILY_GOTHIC = Arrays.asList(
			GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames())
			.contains("MS UI Gothic") ? "MS UI Gothic" : Arrays.asList(
			GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames())
			.contains("Kochi Gothic") ? "Kochi Gothic" : "SansSerif";

	/**
	 * 明朝体のフォント
	 */
	public static final String FONT_FAMILY_MINCHO = Arrays.asList(
			GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames())
			.contains("ＭＳ Ｐ明朝") ? "ＭＳ Ｐ明朝" : Arrays.asList(
			GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames())
			.contains("Kochi Mincho") ? "Kochi Mincho" : "Serif";
	
}
